import matplotlib.pyplot as plt
import matplotlib.colors as mcolors
from matplotlib_colors.colors import colors


# Colors maps
wld = mcolors.ListedColormap([colors['PL_LOSE'], colors['PL_DRAW'], colors['PL_WIN']])
premier_league = mcolors.ListedColormap([colors['PL_PINK'], colors['PL_BLUE'], colors['PL_GREEN']])
team = mcolors.ListedColormap([colors['OPPOSITION'], colors['CONTESTED'], colors['TEAM']])
analyst = mcolors.ListedColormap([colors['OPPOSITION'], colors['CONTESTED'], colors['TEAM']])


excluded_vars = {'colormaps', 'colors', 'plt', 'mcolors', 'excluded_vars', 'var', 'register_cmaps', 'var'}

colormaps = {}
for var in dir():
    if not var.startswith('__') and var not in excluded_vars:
        cmap = eval(var)
        cmap.name = var
        colormaps[var] = cmap
colormap_names = list(colormaps.keys())

def register_cmaps():
    for var, val in globals().items():
        if not var.startswith('__') and var not in excluded_vars:
            print(var, val)
            plt.colormaps.register(val)



from setuptools import setup

long_description = open("README.md").read()

setup(
    name="matplotlib-colors",
    version="1.0.8",
    author="Tom Draper",
    author_email="tomjdraper1@gmail.com",
    license="MIT",
    description="A collection of curated colors and colormaps for matplotlib.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/tom-draper/matplotlib-colors",
    key_words="visualization color colormap colorset matplotlib",
    install_requires=['matplotlib'],
    # py_modules=['matplotlib_colors'],
    packages=["matplotlib_colors"],
    python_requires=">=3.6",
)